# Examples

This directory contains examples of how to use the library.

You have to ways to define your subroutine just like examples here:

- A single `.pyx` file with the Cython declarations.
- A clean `.py` file (or `.pyx`) and a companion `.pxd` file with the Cython declarations in the same directory with the same name.
